==> bitcoin_0.12.1.orig.tar.gz: bitcoin-0.12.1/src/qt/locale/bitcoin_zh.ts <==
<TS language="zh" version="2.1">
<context>
    <name>AddressBookPage</name>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation>余额不足</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>选择...</translation>
    </message>
    <message>
        <source>Pay only the required fee of %1</source>
        <translation>仅支付全额的%1</translation>
    </message>
    <message>
        <source>The recipient address is not valid. Please recheck.</source>
        <translation>收款人地址无效，请再次确认。</translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation>警告：比特币地址无效</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Transaction amounts must be positive</source>
        <translation>转账额度须为正数</translation>
    </message>
    <message>
        <source>Transaction too large for fee policy</source>
        <translation>根据费率标准，本次转账超额</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>超额转账</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat文件受损，修复失败</translation>
    </message>
    <message>
        <source>This help message</source>
        <translation>此条帮助信息</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>正在载入地址...</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>wallet.dat文件加载错误：钱包受损</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>wallet.dat文件加载错误</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>余额不足</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>正在载入钱包...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>再次扫描...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>载入完成</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
</context>
</TS>

==> bitcoin-0.15.1.tar.gz: bitcoin-0.15.1/src/qt/locale/bitcoin_zh.ts <==
<TS language="zh" version="2.1">
<context>
    <name>AddressBookPage</name>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation>余额不足</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>选择...</translation>
    </message>
    <message>
        <source>The recipient address is not valid. Please recheck.</source>
        <translation>收款人地址无效，请再次确认。</translation>
    </message>
    <message>
        <source>Pay only the required fee of %1</source>
        <translation>仅支付全额的%1</translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation>警告：比特币地址无效</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Transaction too large for fee policy</source>
        <translation>根据费率标准，本次转账超额</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>超额转账</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>正在载入地址...</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>余额不足</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>正在载入钱包...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>再次扫描...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>载入完成</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
</context>
</TS>
